carot_conflicts: Conflicts between the carot and other packages

Description Usage Details Examples

View source: R/conflicts.R

Description

This function lists all the conflicts between packages in the carot and other packages that you have loaded.

Usage

1

Details

There are four conflicts that are deliberately ignored: intersect, union, setequal, and setdiff from dplyr. These functions make the base equivalents generic, so shouldn't negatively affect any existing code.

Examples

1

omicsr/CARoT documentation built on Sept. 20, 2021, 1:58 p.m.